# Token Validierung bei sendenden Systemen

**Achtung: Die folgende Dokumentation ist für Softwareentwickler:innen und Betreiber der zentralen Übertragungsinfrastruktur gedacht. Diese Unterlagen befinden sich in einer Überarbeitung und spiegeln nicht den aktuellen Stand wieder.**

Die Authentifizierung von sendenden Systemen erfolgt bei FIT-Connect auf Basis von OAuth 2.0 Client Credentials gemäß [RFC 6749](https://tools.ietf.org/html/rfc6749) und Access Tokens auf Basis von JSON Web Tokens gemäß [RFC 7519](https://datatracker.ietf.org/doc/html/rfc7519). Im Folgenden sollen die nötigen Schritte zur Registrierung und zum Zugriff auf die Schnittstelle des FIT-Connect Zustelldienstes (Submission API) beschrieben werden. Dieses Dokument dokumentiert die implementierten Authentifizierungsmechanismen und macht Vorgaben zur Implementierung der Authentifizierung von sendenden Systemen. Bei der Umsetzung der Authentifizierung kann darüber hinaus auf das vom Projekt FIT-Connect bereitgestellte Software Development Kit (SDK) zurückgegriffen werden, dass die Vorgaben aus diesem Dokument umsetzt bzw. bei deren Umsetzung unterstützt.

![Grafik: Sender JWT-Konzept](/images/oauth/JWT-Konzept.png)

## Zugriff auf die API mittels Access Token
Wenn ein Online-Antragsservice einer Antragsteller:in ermöglichen möchte, eine Einreichung an die FIT-Connect Submission API zu übermitteln, muss dieser zunächst mithilfe der OAuth Client-Credentials beim OAuth-Server einen Berechtigungstoken (im Folgenden "Access Token") nach dem Standard *JSON Web Token* gemäß [RFC 7519](https://tools.ietf.org/html/rfc7519)) abrufen. Dieser vom OAuth-Server signierte Access Token enthält den Public-Key des Online-Antragsdienstes, der bei der Registrierung im Self-Service-Portal festgelegt wurde. Aus Sicht von API-Clients sind die Inhalte des Tokens gemäß OAuth-Spezifikation als bedeutungslos anzusehen und SOLLTEN daher NICHT interpretiert werden. Eine Prüfung des Access Token auf Korrektheit und Gültigkeit erfolgt intern.

### Payload des Access Tokens
Der hier beschriebene Payload des Access Tokens dient lediglich der Dokumentation/Spezifikation. Im Payload des signierten Access Token werden vom Autorisierungsdienst die folgenden [standardisierten Felder](https://www.iana.org/assignments/jwt/jwt.xhtml) gesetzt:

| Feld             | Inhalt                                | Erläuterung |
| ---------------- | ------------------------------------- | --------------- |
| `sub` (Subject)  | Client ID des sendenden Systems | Beim gewählten Client Credential Flow wird hier die Client ID des System eingetragen.|
| `aud` (Audience) | URL der Submission API       | Die URL der API des Zustelldienstes, für den der Token ausgestellt wurde, gemäß [RFC 7519, Abschnitt 4.1.3](https://datatracker.ietf.org/doc/html/rfc7519#section-4.1.3). |
| `scope`          | Zustellberechtigungs-Scopes     | Eine Liste der Zustellberechtigungs-Scopes, separiert mit Leerzeichen gemäß [RFC 6749, Abschnitt 3.3](https://datatracker.ietf.org/doc/html/rfc6749#section-3.3). Für sendende System sind [folgende Scopes](/details/authentication/scopes-sender.md) zu nutzen. |
| `iss` (Issuer)   | URL des Autorisierungsservers   | Die URL des Autorisierungsservers, der das Token ausgestellt hat. |
| `exp`            | Unix Timestamp                  | Zeitpunkt, wann der Token abläuft, als Unix Timestamp (Token DARF max. 24 Stunden gültig sein; vgl. [BSI APP.3.1](https://www.bsi.bund.de/SharedDocs/Downloads/DE/BSI/Grundschutz/Kompendium_Einzel_PDFs/06_APP_Anwendungen/APP_3_1_Webanwendungen_Edition_2020.pdf?__blob=publicationFile&v=1)) |
| `iat`            | Unix Timestamp                  | Zeitpunkt, wann der Token vom Autorisierungsdienst ausgestellt wurde, als Unix Timestamp |
| `jti` (JWT ID)   | ID des Tokens                   | Eindeutige ID des ausgestellten Tokens. |
| `client_id`      | Identisch mit `sub`             |  |

**Beispiel-Payload eines Access Tokens:**

```json
{
  "sub": "lxnsidjbdd6bk",
  "aud": "https://submission-api-testing.fit-connect.fitko.dev",
  "scope": "send:region:DE01010 send:region:DE010109990",
  "iss": "https://auth-testing.fit-connect.fitko.dev",
  "exp": 1627044703,
  "iat": 1627042903,
  "jti": "bU9uS7fTLbQ",
  "client_id": "lxnsidjbdd6bk"
}
```
