# Token Validierung bei empfangenden Systemen

**Achtung: Die folgende Dokumentation ist für Softwareentwickler:innen und Betreiber der zentralen
Übertragungsinfrastruktur gedacht. Diese Unterlagen befinden sich in einer Überarbeitung und spiegeln nicht den
aktuellen Stand wieder.**

Die Authentifizierung von empfangenden Systemen erfolgt bei FIT-Connect auf Basis von OAuth 2.0 Client Credentials
gemäß [RFC 6749](https://tools.ietf.org/html/rfc6749) und Access Tokens auf Basis von JSON Web Tokens
gemäß [RFC 7519](https://datatracker.ietf.org/doc/html/rfc7519). Zum Abruf von Anträgen müssen sich empfangende Systeme
mithilfe von OAuth 2.0 Client-Credentials beim Autorisierungsdienst authentifizieren. Die hierfür nötigen Client
erhalten Behörden und andere Abrufberechtigte, nach einer Anmeldung im Self-Service-Portal der FITKO. (TODO: link)

Zum Abruf von Anträgen müssen sich empfangende Systeme zunächst mithilfe der OAuth Client-Credentials beim OAuth-Server
ein Berechtigungstoken (im Folgenden "Access Token") nach dem Standard JSON Web Token
gemäß [RFC 7519](https://tools.ietf.org/html/rfc7519) abrufen. Dieser vom OAuth-Server signierte Token kann anschließend
genutzt werden, um sich gegenüber der Submission API eines Zustelldienstes zu authentifizieren.

Bei erfolgreicher Registrierung erhält die für den Zustellpunkt verantwortliche Behörde OAuth2-Zugangsdaten für den
Authentifizierungstyp "Client-Credentials" (`client_id` und `client_secret`). Mit diesen kann sich das empfangende
System beim Authentifizuerungsdienst authentifizieren und erhält einen Access Token im JSON Web Token-Format (JWT). Mit
diesem Access Token ist anschließend ein Abruf der im Zustelldienst hinterlegten Anträge möglich.

## Zugriff auf die API mittels Access Token

Das Access Token für empfangende Systeme wird vom Autorisierungsdienst erzeugt und DARF vom empfangenden System NIEMALS
an dritte Systeme (mit Außnahme des Zustelldienstes zum Zwecke der Authentifizierung) weitergegeben werden. Das Access
Token für empfangende Systeme wird beim Zugriff auf die Submission API im `Authorization`-Header mit `Bearer`
-Authentifizierungsschema gemäß [RFC 6750](https://datatracker.ietf.org/doc/html/rfc6750) an den Zustelldienst
übermittelt:

**Beispiel**

```http
POST /v1/submissions HTTP/1.1
Host: submission-api-testing.fit-connect.fitko.dev
Authorization: Bearer ey...
```

### Header des Access Tokens für empfangende Systeme

Im Header des Access Tokens für empfangende Systeme werden vom Autorisierungsdienst gemäß den Vorgaben
aus [RFC 7519](https://tools.ietf.org/html/rfc7519) die folgende Header-Attribute gesetzt:

| Feld  | Inhalt   | Erläuterung |
| ----- | -------- | --------------- |
| `typ` | `at+jwt` | Es handelt sich um ein Access Token im JSON Web Token (JWT) Format. |
| `alg` | `PS512`  | Zur Signaturerstellung wird der Signaturalgorithmus RSASSA-PSS mit SHA-512 und MGF1 mit SHA-512 verwendet. |
| `kid` | String   | ID des Schlüssels mit dem das Access Tokens ausgestellt wurde. |

**Beispiel**

```json
{
  "kid": "CXup",
  "typ": "at+jwt",
  "alg": "PS512"
}
```

### Payload des Access Tokens für empfangende Systeme

Im Payload des signierten Access Token MÜSSEN mindestens die
folgenden [standardisierten Felder](https://www.iana.org/assignments/jwt/jwt.xhtml) gesetzt sein:

| Feld             | Inhalt                        | Erläuterung |
| ---------------- | ----------------------------- | --------------- |
| `sub` (Subject)  | ID des empfangenden Systems   | Identifiziert ein empfangendes System. Festgelegt im Autorisierungsdienst. |
| `aud` (Audience) | URL der Submission API     | Die URL der API des Zustelldienstes, für den der Token ausgestellt wurde, gemäß [RFC 7519, Abschnitt 4.1.3](https://datatracker.ietf.org/doc/html/rfc7519#section-4.1.3). |
| `scope`          | Zustellberechtigungs-Scopes   | Eine Liste der Zustellberechtigungs-Scopes, separiert mit Leerzeichen gemäß [RFC 6749, Abschnitt 3.3](https://datatracker.ietf.org/doc/html/rfc6749#section-3.3). Für sendende System sind [folgende Scopes](/details/authentication/scopes-subscriber.md) zu nutzen. |
| `iss` (Issuer)   | URL des Autorisierungsservers | URL des Autorisierungsservers der das Access Token ausgestellt hat. |
| `exp`            | Unix Timestamp                | Ablaufzeitpunkt des Access Tokens (DARF max. 2 Stunden gültig sein; vgl. [BSI APP.3.1](https://www.bsi.bund.de/SharedDocs/Downloads/DE/BSI/Grundschutz/Kompendium_Einzel_PDFs/06_APP_Anwendungen/APP_3_1_Webanwendungen_Edition_2020.pdf?__blob=publicationFile&v=1)) |
| `iat`            | Unix Timestamp                | Ausstellungszeitpunkt des Access Tokens. |
| `jti` (JWT ID)   | ID des Tokens                 | Eindeutige ID des ausgestellten Tokens. |
| `client_id`      | Identisch mit `sub`           |  |

**Beispiel-Payload eines Access Tokens:**

```json
{
  "sub": "epie1quee7eeR",
  "aud": "https://submission-api-testing.fit-connect.fitko.dev",
  "scope": "subscribe:destination:36141427-d405-40a4-8f8b-3592d544e85b manage:destination:36141427-d405-40a4-8f8b-3592d544e85b",
  "iss": "https://auth-testing.fit-connect.fitko.dev",
  "exp": 1627045703,
  "iat": 1627043903,
  "jti": "aeveeSa3ohl",
  "client_id": "epie1quee7eeR"
}
```
